@@ -32,6 +32,7 @@ import urllib3
 from pyspark.sql import SparkSession
 
 import sparkmon
+from sparkmon.logger import log
 
 
 class SparkMon(threading.Thread):
@@ -79,6 +80,11 @@ class SparkMon(threading.Thread):
         self.updateEvent = threading.Event()
         self.timeout_sec = 20
 
+        for t in threading.enumerate():
+            if t.name == "MainThread":
+                self.main_thread = t
+                break
+
     def stop(self) -> None:
         """Don't continue to run the loop, and exit safely the thread."""
         self.stop_event.set()
@@ -89,23 +95,28 @@ class SparkMon(threading.Thread):
 
     def is_main_thread_alive(self) -> bool:
         """Check if the main thread is alive."""
-        for t in threading.enumerate():
-            if t.name == "MainThread":
-                return t.is_alive()
+        return self.main_thread.is_alive()
+
+    def should_stop(self) -> bool:
+        """Check if we should stop the thread loop."""
+        # This is a Thread class (non daemon) meaning it can run for ever and block the exit of Python at the end.
+        # This is why we check if the main thread is finished to stop SparkMon in a smooth manner at exit:
+        if not self.is_main_thread_alive():
+            self.stop()
+
+        return self.stopped()
 
     def run(self) -> None:
         """Overrides Thread method."""
         self.start_time = time.time()
 
-        while True:
-            if self.stopped():
+        # We wait at the beginning of the loop, and not at the end,
+        # to let the Spark session starts and MLflow run initializes at the beginning.
+        # It is better to use join on the main_thread than a sleep() or a wait() because it is delaying the exit
+        while not self.main_thread.join(self.period):
+            if self.should_stop():
                 return
 
-            # This is a Thread class (non daemon) meaning it can run for ever and block the exit of Python at the end.
-            # This is why we check if the main thread is finished to stop SparkMon in a smooth manner at exit:
-            if not self.is_main_thread_alive():
-                self.stop()
-
             # Updating the application DB
             try:
                 # Callbacks are reading application, so let's make thread safe with a lock:
@@ -125,22 +136,19 @@ class SparkMon(threading.Thread):
                 # so that the main Python process can exit smoothly
                 elapsed_sec = time.time() - self.start_time
                 if elapsed_sec > self.timeout_sec:
-                    # Not need to print if we exited or stopped
+                    # Not need to log if we exited or stopped
                     if not self.stopped():
-                        print(
-                            f"sparkmon: Info, Spark application not available anymore, stopping monitoring. (Exception: {ex})"
-                        )
+                        log.info(f"Spark application not available anymore, stopping monitoring. (Exception: {ex})")
                     self.stop()
                     return
 
             # Run the callback
             self.callbacks_run()
 
-            if self.stopped():
+            if self.should_stop():
                 return
 
             self.updateEvent.set()
-            time.sleep(self.period)
 
     def callbacks_run(self):
         """Running the callbacks."""
